@@ -231,10 +231,13 @@ class PyMvnGit:
                   prettyTable.addRow(columns)
                   idx_lin    += 1
    
-              prettyTable.sortByColumn(0)   
-              prettyTable.numberSeparator = True
-              prettyTable.ascendingOrder(True)
-              Console.printTable("{}MACROS repository: {}{}{}".format(Colors.WHITE,Colors.IGREEN,self._currentDir(),Colors.GREEN), prettyTable, tableArgs)    
+              if idx_line > 1:
+                 prettyTable.sortByColumn(0)   
+                 prettyTable.numberSeparator = True
+                 prettyTable.ascendingOrder(True)
+                 Console.printTable("{}MACROS{}".format(Colors.WHITE, Colors.GREEN), prettyTable, tableArgs)    
+              else:
+                 Console.printLine("No macro found!")
            else:   
               Console.printHeaderCommand("{}MACROS repository: {}".format(Colors.RESET,Colors.IGREEN + self._currentDir() + Colors.GREEN))  
               for r in records:
